import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useContext, useEffect } from "react";
import { describe, PropTypes } from "@elliemae/ds-props-helpers";
import { styled } from "@elliemae/ds-system";
import { PopperPositions as positions } from "@elliemae/ds-popper";
import { TruncatedTooltipContext } from "./TooltipTextProvider.js";
const isEllipsisActive = ({ offsetWidth, scrollWidth }) => offsetWidth < scrollWidth;
const Text = styled.span`
  text-overflow: ellipsis;
  white-space: nowrap;
  overflow: hidden;
  display: inline-block;
  max-width: 100%;
`;
const DSTruncatedTooltipText = ({
  containerProps = {},
  value = "",
  zIndex = 3e3,
  // https://jira.elliemae.io/browse/PUI-1755 https://jira.elliemae.io/browse/PUI-8732
  ...otherTextProps
}) => {
  const tooltipContext = useContext(TruncatedTooltipContext);
  useEffect(() => {
    if (zIndex && tooltipContext) tooltipContext.setZIndex(zIndex);
  }, [zIndex]);
  if (!tooltipContext) return value;
  const { showTooltip, hideTooltip } = tooltipContext;
  const handleMouseEnter = (e) => {
    const { target } = e;
    if (target && isEllipsisActive(target, target.getBoundingClientRect())) {
      showTooltip(
        {
          value,
          reference: target
        },
        e
      );
    }
  };
  const handleMouseLeave = (e) => {
    hideTooltip({ reference: e.target });
  };
  const handlers = showTooltip ? { onMouseEnter: handleMouseEnter, onMouseLeave: handleMouseLeave } : {};
  return /* @__PURE__ */ jsx(Text, { ...containerProps, ...otherTextProps, ...handlers, children: value });
};
DSTruncatedTooltipText.defaultProps = {
  value: "",
  zIndex: 110
};
const truncatedTooltipTextProps = {
  containerProps: PropTypes.object.description("Set of Properties attached to the main container"),
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).description(
    "Text that when truncated will trigger the tooltip interaction"
  ),
  tooltipPlacement: PropTypes.oneOf([
    positions.AUTO_START,
    positions.AUTO_END,
    positions.AUTO,
    positions.TOP_START,
    positions.TOP,
    positions.TOP_END,
    positions.RIGHT_START,
    positions.RIGHT,
    positions.RIGHT_END,
    positions.BOTTOM_START,
    positions.BOTTOM,
    positions.BOTTOM_END,
    positions.LEFT_START,
    positions.LEFT,
    positions.LEFT_END
  ]).description("Position of the tooltip"),
  tooltipDelay: PropTypes.number.description("Delay to show the tooltip"),
  zIndex: PropTypes.number.description("override default zIndex").defaultValue(110)
};
DSTruncatedTooltipText.defaultProps = {
  containerProps: {},
  value: "",
  tooltipPlacement: void 0,
  tooltipDelay: void 0
};
DSTruncatedTooltipText.displayName = "DSTruncatedTooltipText";
const TruncatedTooltipTextWithSchema = describe(DSTruncatedTooltipText);
TruncatedTooltipTextWithSchema.propTypes = truncatedTooltipTextProps;
var DSTruncatedTooltipText_default = DSTruncatedTooltipText;
export {
  DSTruncatedTooltipText,
  TruncatedTooltipTextWithSchema,
  DSTruncatedTooltipText_default as default
};
//# sourceMappingURL=DSTruncatedTooltipText.js.map
