import * as React from "react";
import { jsx } from "react/jsx-runtime";
import { useState, useMemo, useEffect } from "react";
import { DSTooltipV3 } from "@elliemae/ds-tooltip-v3";
import { useMemoMergePropsWithDefault, useValidateTypescriptPropTypes, describe } from "@elliemae/ds-props-helpers";
import { DSTruncateTextWithTooltipDatatestid } from "./DSTruncateTextWIthTooltipDatatestid.js";
import { Text } from "./styles.js";
import {
  DSTruncateTextWithTooltipPropTypesSchema,
  defaultProps
} from "./react-desc-prop-types.js";
const DSTruncateTextWithTooltip = (props) => {
  const propsWithDefault = useMemoMergePropsWithDefault(props, defaultProps);
  useValidateTypescriptPropTypes(
    propsWithDefault,
    DSTruncateTextWithTooltipPropTypesSchema,
    "DSTruncateTextWithTooltip"
  );
  const { text, tooltipProps } = propsWithDefault;
  const [textWrapperEl, setTextWrapperEl] = useState(null);
  const [isShowingEllipsis, setIsShowingEllipsis] = useState(false);
  const resizeObserver = useMemo(
    () => new ResizeObserver((entries) => {
      if (entries.length) {
        const [textWrapperEntry] = entries;
        const el = textWrapperEntry.target;
        setIsShowingEllipsis(el?.scrollWidth > el?.clientWidth);
      }
    }),
    []
  );
  useEffect(() => {
    if (textWrapperEl) {
      setIsShowingEllipsis(textWrapperEl?.scrollWidth > textWrapperEl?.clientWidth);
      resizeObserver.observe(textWrapperEl);
    }
    return () => {
      if (textWrapperEl) {
        resizeObserver.unobserve(textWrapperEl);
      }
    };
  }, [resizeObserver, textWrapperEl]);
  if (isShowingEllipsis)
    return /* @__PURE__ */ jsx(DSTooltipV3, { text, ...tooltipProps, children: /* @__PURE__ */ jsx(Text, { innerRef: setTextWrapperEl, tabIndex: 0, "data-testid": DSTruncateTextWithTooltipDatatestid.TEXT, children: text }) });
  return /* @__PURE__ */ jsx(Text, { innerRef: setTextWrapperEl, "data-testid": DSTruncateTextWithTooltipDatatestid.TEXT, children: text });
};
const DSTruncateTextWithTooltipWithSchema = describe(DSTruncateTextWithTooltip);
DSTruncateTextWithTooltipWithSchema.propTypes = DSTruncateTextWithTooltipPropTypesSchema;
export {
  DSTruncateTextWithTooltip,
  DSTruncateTextWithTooltipWithSchema
};
//# sourceMappingURL=DSTruncateTextWithTooltip.js.map
