import * as React from "react";
import { useCallback, useRef } from "react";
const useCancellableDelayedCallback = (cb, delay) => {
  const timeoutRef = useRef();
  const cancel = useCallback(() => {
    const timeoutId = timeoutRef.current;
    if (timeoutId) {
      timeoutRef.current = void 0;
      clearTimeout(timeoutId);
    }
  }, [timeoutRef]);
  const delayedCb = useCallback(
    (...args) => {
      timeoutRef.current = setTimeout(() => cb(...args), delay);
    },
    [cb, delay]
  );
  return [delayedCb, cancel];
};
var useCancellableDelayedCallback_default = useCancellableDelayedCallback;
export {
  useCancellableDelayedCallback_default as default,
  useCancellableDelayedCallback
};
//# sourceMappingURL=useCancellableDelayedCallback.js.map
